@@ -23,7 +23,7 @@ if ($action ~~ 'list'){
 }
 
 if ($action ~~ 'updatedb'){
-    $rvm->update_db;
+    $rvm->updatedb;
     exit 0;
 }
 
@@ -53,7 +53,7 @@ This is an unstable development release not ready for production!
 
 =head1 VERSION
 
-Version 0.03.05
+Version 0.03.06
 
 =head1 SYNOPSIS
 
